@@ -54,9 +54,10 @@ new_defaults = function(value = list()) {
 #'
 #'   A list of available options:
 #'   \url{https://yihui.name/knitr/options/#chunk_options}
-#' @note \code{opts_current} is read-only in the sense that it does nothing if
-#'   you call \code{opts_current$set()}; you can only query the options via
-#'   \code{opts_current$get()}.
+#' @note \code{opts_current} should be treated as read-only and you are supposed
+#'   to only query its values via \code{opts_current$get()}. Technically you
+#'   could also call \code{opts_current$set()} to change the values, but you are
+#'   not recommended to do so unless you understand the consequences.
 #' @export
 #' @examples opts_chunk$get('prompt'); opts_chunk$get('fig.keep')
 opts_chunk = new_defaults(list(
@@ -108,8 +109,10 @@ opts_chunk_attr = local({
   opts$external = opts$sanitize = NULL  # hide these two rare options
   opts$fig.process = 'function'
   opts$fig.asp = 'numeric'
+  opts$fig.dim = 'list'
   opts$R.options = 'list'
   opts$cache.comments = 'logical'
+  opts$animation.hook = list('ffmpeg', 'gifski')
   opts
 })
 
@@ -118,9 +121,9 @@ opts_chunk_attr = local({
 #' We do not have to use the chunk option names given in \pkg{knitr}; we can set
 #' aliases for them. The aliases are a named character vector; the names are
 #' aliases and the elements in this vector are the real option names.
-#' @param ... named arguments (argument names are aliases, and argument values
-#'   are real chunk options)
-#' @return NULL (\code{opts_knit$get('aliases')} is modified as the side effect)
+#' @param ... Named arguments. Argument names are aliases, and argument values
+#'   are real option names.
+#' @return \code{NULL}. \code{opts_knit$get('aliases')} is modified as the side effect.
 #' @export
 #' @examples set_alias(w = 'fig.width', h = 'fig.height')
 #' # then we can use options w and h in chunk headers instead of fig.width and fig.height
@@ -157,8 +160,7 @@ set_alias = function(...) {
 opts_knit = new_defaults(list(
   progress = TRUE, verbose = FALSE, width = 75L, eval.after = 'fig.cap',
   base.dir = NULL, base.url = NULL, root.dir = NULL, child.path = '',
-  upload.fun = identity, animation.fun = hook_ffmpeg_html,
-  global.device = FALSE, global.par = FALSE,
+  upload.fun = identity, global.device = FALSE, global.par = FALSE,
   concordance = FALSE, documentation = 1L, self.contained = TRUE,
   unnamed.chunk.label = 'unnamed-chunk', highr.opts = NULL,
 
