@@ -134,19 +134,7 @@ plot2dev = function(plot, name, dev, device, path, width, height, options) {
 
   # compile tikz to pdf
   if (dev == 'tikz' && options$external) {
-    unlink(pdf.plot <- paste0(name, '.pdf'))
-    owd = setwd(dirname(path))
-    # add old wd to TEXINPUTS (see #188)
-    oti = Sys.getenv('TEXINPUTS'); on.exit(Sys.setenv(TEXINPUTS = oti))
-    Sys.setenv(TEXINPUTS = paste(owd, oti, sep = .Platform$path.sep))
-    tinytex::latexmk(basename(path), getOption('tikzDefaultEngine'), emulation = TRUE)
-    setwd(owd)
-    if (!file.exists(pdf.plot)) {
-      if (file.exists(log <- paste(name, 'log', sep = '.')))
-        message(paste(readLines(log), collapse = '\n'))
-      stop2('failed to compile ', path, ' to PDF')
-    }
-    path = pdf.plot
+    path = tinytex::latexmk(path, getOption('tikzDefaultEngine'))
   }
 
   fig_process(options$fig.process, path)
@@ -379,6 +367,7 @@ include_graphics = function(
     i = file.exists(path2)
     path[i] = path2[i]
   }
+  path = native_encode(path)
   structure(path, class = c('knit_image_paths', 'knit_asis'), dpi = dpi)
 }
 
